==> haskell-snap-core-1.0.5.1-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-EqcYpBOdZI1BxEOr5GNNhG
key:                  snap-core-1.0.5.1-EqcYpBOdZI1BxEOr5GNNhG
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  b61a577902d669715fb79f324a36f2e3
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-EqcYpBOdZI1BxEOr5GNNhG
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    attoparsec-0.14.4-D7CECqktDgS2fYWStxbJq3 base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    io-streams-1.5.2.2-BnxLvKN1XwkGmzDXcimoxX
    lifted-base-0.2.3.12-CaZxFVx2QaKIfHbtq0tB6m
    monad-control-1.0.3.1-EMymL5qvPF86Ly30QNsrD5 mtl-2.2.2
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    network-uri-2.6.4.2-8swvJWOy75N7pbfI8WzbN
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    random-1.2.1.3-2Hw42CquWtj55joOjOmzRr
    readable-0.3.1-IDsQMpnz7oHK9VbHbSIfA7
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-C48guHuMOb9AOa55HXY0p9
    unix-compat-0.7.4.1-51QWcgHKY9Q2M4gdNfLh1f
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.5.1-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-9X6pa9oKF1nJv7gVv8Ebwn
key:                  snap-core-1.0.5.1-9X6pa9oKF1nJv7gVv8Ebwn
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  3a0e68c3c4f787ca7ae4e00dfb46eac1
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-9X6pa9oKF1nJv7gVv8Ebwn
depends:
    HUnit-1.6.2.0-9X1R1uFIABDFmOEozkgarM
    attoparsec-0.14.4-IXbcbJGX0cBC8WVvSy4ntj base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3FuXchFPXBfLVJKu7fam1O
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    hashable-1.4.5.0-FhpNKvHQsJeLXuGJFx8piW
    io-streams-1.5.2.2-zFOPEd0sHqDDPkF4ioKJJ
    lifted-base-0.2.3.12-7CBBhkae1iy2FmbQDgCauu
    monad-control-1.0.3.1-69dnLrrVpTh4jQgsdou34S mtl-2.2.2
    network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    network-uri-2.6.4.2-BPG1Yj05GAIIauIotQ4jTb
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    random-1.2.1.3-LY8g0he9kPzH0WCF9vQLty
    readable-0.3.1-IDsQMpnz7oHK9VbHbSIfA7
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-GqnHbqWDT0e8qlqX7fWzwX
    unix-compat-0.7.4.1-FHEkyK2HAgOIviNihEwrGS
    unordered-containers-0.2.20-79maJZZuZDu8bRI1CHuoJG
    vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
